@@ -46,6 +46,8 @@ class CxReader(XMLReader):
         """
         cur_doc = self.cur_doc
         plain_text = " ".join(cur_doc.xpath('.//tei:body//tei:p//text()', namespaces=self.nsmap))
+        plain_text = " ".join(plain_text.split())
+        # plain_text = plain_text.replace('ß', 'ss')
         if self.char_limit:
             return plain_text[:5000]
         return plain_text
@@ -54,7 +56,8 @@ class CxReader(XMLReader):
 
         """ yields chunks of the object's plain text
 
-        :return:  yields dicts like `{"id": "example_text.txt", "chunk_nr": "001", "text": "text of chunk", "char_count": 13}`
+        :return:  yields dicts like\
+            `{"id": "example_text.txt", "chunk_nr": "001", "text": "text of chunk", "char_count": 13}`
         :rtype: dict
         """
         return get_chunks(self.plain_text, self.chunk_size, self.file_name)
@@ -99,7 +102,7 @@ class CxReader(XMLReader):
             self.file_name = self.file
 
 
-def yield_chunks(files, char_limit=True):
+def yield_chunks(files, chunk_size=CHUNK_SIZE, char_limit=True):
 
     """ utility function to yield chunks from a collection of files
 
@@ -111,13 +114,13 @@ def yield_chunks(files, char_limit=True):
 
     """
     for x in files:
-        doc = CxReader(xml=x, char_limit=char_limit)
+        doc = CxReader(xml=x, char_limit=char_limit, chunk_size=chunk_size)
         chunks = doc.yield_chunks()
         for y in chunks:
             yield y
 
 
-def chunks_to_df(files, char_limit=True):
+def chunks_to_df(files, char_limit=True, chunk_size=CHUNK_SIZE):
 
     """ reads chunks from a list of files into a `pandas.DataFrame`
 
@@ -127,7 +130,7 @@ def chunks_to_df(files, char_limit=True):
     :return: a pandas.Dataframe with columns `id`, `chunk_nr`, `text`, and `char_count`
     :rtype: pandas.Dataframe
     """
-    df = pd.DataFrame(yield_chunks(files, char_limit=char_limit))
+    df = pd.DataFrame(yield_chunks(files, char_limit=char_limit, chunk_size=chunk_size))
     return df
 
 
@@ -136,7 +139,7 @@ class CxCollate():
     """
 
     def chunk_df(self):
-        return chunks_to_df(self.files, self.char_limit)
+        return chunks_to_df(self.files, char_limit=self.char_limit, chunk_size=self.chunk_size)
 
     def collate(self):
         print(f"start collating {self.file_count} Documents at {datetime.now()}\n")
@@ -144,7 +147,7 @@ class CxCollate():
         files = []
         try:
             os.makedirs(self.output_dir)
-        except Exception as e:
+        except Exception as e:  # noqa: F841
             print(f'{self.output_dir}: {self.output_dir} already exists')
         counter = 0
         df = self.df
