@@ -1,8 +1,7 @@
 """Console script for acdh_collatex_utils."""
-import sys
 import click
 
-from . acdh_collatex_utils import CUSTOM_XSL, CHUNK_SIZE, CxCollate
+from . acdh_collatex_utils import CxCollate
 
 
 @click.command()  # pragma: no cover
@@ -10,7 +9,8 @@ from . acdh_collatex_utils import CUSTOM_XSL, CHUNK_SIZE, CxCollate
 @click.option('--nr/--r', default=False, show_default=True)  # pragma: no cover
 def collate(glob_pattern, nr):  # pragma: no cover
     """Console script to flatten XML/TEI files of a work."""
-    new_glob_pattern = f"{glob_pattern}/*.xml"
+    new_glob_pattern = f"{glob_pattern}"
+    print(new_glob_pattern)
     output_dir = new_glob_pattern.replace("*.xml", 'collated')
 
     out = CxCollate(
@@ -29,7 +29,7 @@ def collate(glob_pattern, nr):  # pragma: no cover
 
     click.echo(
         click.style(
-            f"\n################################\n",
+            "\n################################\n",
             fg='green'
         )
     )
